import { app } from '@/app.ts';
// import mockTickets from './mock/data.ts';
import { TicketModel } from './model.ts';
import { Sequelize, Op, WhereOptions } from 'sequelize';

// 定义搜索参数类型
type SearchTicketsParams = {
  current?: number;
  pageSize?: number;
  search?: string;
  status?: string;
  type?: string;
  sort?: string;
  order?: 'asc' | 'desc';
  uid?: string;
  startDate?: string;
  endDate?: string;
};

app
  .route({
    path: 'ticket',
    key: 'list',
  })
  .define(async (ctx) => {
    const searchForm = ctx.query?.data || {} as SearchTicketsParams;
    const { 
      current = 1, 
      pageSize = 10,
      search,
      status,
      type,
      sort = 'createdAt',
      order = 'desc',
      uid,
      startDate,
      endDate
    } = searchForm;
    
    // 构建查询条件
    let where: any = {};
    
    // 如果提供了搜索关键词，同时搜索标题和描述
    if (search) {
      where[Op.or] = [
        { title: { [Op.like]: `%${search}%` } },
        { description: { [Op.like]: `%${search}%` } }
      ];
    }
    
    // 添加其他过滤条件
    if (status) where.status = status;
    if (type) where.type = type;
    if (uid) where.uid = uid;
    
    // 日期范围过滤
    if (startDate || endDate) {
      const dateFilter: any = {};
      if (startDate) dateFilter[Op.gte] = new Date(startDate);
      if (endDate) dateFilter[Op.lte] = new Date(endDate);
      where.createdAt = dateFilter;
    }

    // 验证排序字段是否有效，防止SQL注入
    const validSortFields = ['id', 'title', 'status', 'type', 'price', 'createdAt', 'updatedAt'];
    const sortField = validSortFields.includes(sort) ? sort : 'createdAt';
    const sortOrder = order?.toUpperCase() === 'ASC' ? 'ASC' : 'DESC';
    
    const { rows, count } = await TicketModel.findAndCountAll({
      where,
      offset: (current - 1) * pageSize,
      limit: pageSize,
      order: [[sortField, sortOrder]],
    });
    
    ctx.body = {
      list: rows,
      pagination: {
        total: count,
        current: Number(current),
        pageSize: Number(pageSize),
        totalPages: Math.ceil(count / Number(pageSize)),
      },
    };
  })
  .addTo(app);

app
  .route({
    path: 'ticket',
    key: 'update',
  })
  .define(async (ctx) => {
    const data = ctx.query?.data || {};
    const { id, ...updateData } = data;
    if (!id) {
      ctx.throw(400, 'ID is required for update');
    }
    const ticket = await TicketModel.findByPk(id);
    if (!ticket) {
      ctx.throw(404, 'Ticket not found');
    }
    await ticket.update(updateData);
    ctx.body = ticket;
  })
  .addTo(app);

app
  .route({
    path: 'ticket',
    key: 'delete',
  })
  .define(async (ctx) => {
    const data = ctx.query?.data || {};
    const { id } = data;
    if (!id) {
      ctx.throw(400, 'ID is required for deletion');
    }
    const ticket = await TicketModel.findByPk(id);
    if (!ticket) {
      ctx.throw(404, 'Ticket not found');
    }
    await ticket.destroy();
    ctx.body = { message: 'Ticket deleted successfully' };
  })
  .addTo(app);
